# unitorch.models.clip

## ClipProcessor

::: unitorch.models.clip.ClipProcessor

## ClipForPretrain

::: unitorch.models.clip.ClipForPretrain

## ClipForClassification

::: unitorch.models.clip.ClipForClassification

## ClipForTextClassification

::: unitorch.models.clip.ClipForTextClassification

## ClipForImageClassification

::: unitorch.models.clip.ClipForImageClassification
